gg_mq

package
v0.3.71 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2025 License: BSD-3-Clause Imports: 4 Imported by: 0

README

Message Queue

icon

Message Queue implementation that support drivers for:

  • AMQP: RabbitMQ client (github.com/streadway/amqp)

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MQHelper

type MQHelper struct {
}
var MQ *MQHelper

func (*MQHelper) Build

func (instance *MQHelper) Build(config interface{}) (mq_commons.IDriver, error)

Build return a client implementation if supported config: ex {"protocol":"amqp","secret":"1234","url":"amqp://test:test@localhost:5672/"}

Directories

Path Synopsis
mq_drivers
driver_mqtt_aws/topics/lifecycle
Package lifecycle provides topics to intercept thing lifecycle & subscription events
Package lifecycle provides topics to intercept thing lifecycle & subscription events
driver_mqtt_aws/topics/registry
Package registry provides topics for Device registry operations
Package registry provides topics for Device registry operations

Jump to