lifecycle

package
v0.3.71 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2025 License: BSD-3-Clause Imports: 0 Imported by: 0

Documentation

Overview

Package lifecycle provides topics to intercept thing lifecycle & subscription events

Index

Constants

const (

	// AnyConnected : When subscribed to this topic gives events for all devices connecting to the iot gateway
	AnyConnected string = connected + "+"

	// AnyDisconnected : When subscribed to this topic gives events for all devices disconnected from the iot gateway
	AnyDisconnected string = disconnected + "+"

	// AnySubscribed : When subscribed to this topic gives events for all subscriptions being performed on iot gateway
	AnySubscribed string = subscribed + "+"

	// AnyUnsubscribed : When subscribed to this topic gives events for all unsubscribe operations being performed on iot gateway
	AnyUnsubscribed string = unsubscribed + "+"
)

Variables

This section is empty.

Functions

func ClientConnected

func ClientConnected(clientId string) string

ClientConnected builds topic which will listen to connection event for clientId

func ClientDisconnected

func ClientDisconnected(clientId string) string

ClientDisconnected builds topic which will listen to disconnection event for clientId

func OnSubscribed

func OnSubscribed(topic string) string

OnSubscribed builds topic which will listen to all subscription events for specified topic

func OnUnsubscribed

func OnUnsubscribed(topic string) string

OnUnsubscribed builds topic which will listen to all unsubscribe events for specified topic

Types

This section is empty.

Jump to