registry

package
v0.3.71 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2025 License: BSD-3-Clause Imports: 0 Imported by: 0

Documentation

Overview

Package registry provides topics for Device registry operations

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ThingCreated

func ThingCreated(thingName string) string

ThingCreated builds topic which listens for thing creation event for specified thingName

func ThingDeleted

func ThingDeleted(thingName string) string

ThingDeleted builds topic which listens for thing deletion event for specified thingName

func ThingGroupCreated

func ThingGroupCreated(groupName string) string

ThingGroupCreated builds topic which listens for thing group creation event for specified groupName

func ThingGroupDeleted

func ThingGroupDeleted(groupName string) string

ThingGroupDeleted builds topic which listens for thing group deleting event for specified groupName

func ThingGroupHierarchyAdded

func ThingGroupHierarchyAdded(parentThingGroupName, childThingGroupName string) string

ThingGroupHierarchyAdded builds topic which listens for change in thing group hierarchy for addition event with specified parentThingGroupName & childThingGroupName

func ThingGroupHierarchyRemoved

func ThingGroupHierarchyRemoved(parentThingGroupName, childThingGroupName string) string

ThingGroupHierarchyRemoved builds topic which listens for change in thing group hierarchy for removal event with specified parentThingGroupName & childThingGroupName

func ThingGroupMembershipAdded

func ThingGroupMembershipAdded(thingGroupName, thingName string) string

ThingGroupMembershipAdded builds topic which listens for thing group membership addition event for specified thingGroupName & thingName

func ThingGroupMembershipRemoved

func ThingGroupMembershipRemoved(thingGroupName, thingName string) string

ThingGroupMembershipRemoved builds topic which listens for thing group membership removal event for specified thingGroupName & thingName

func ThingGroupUpdated

func ThingGroupUpdated(groupName string) string

ThingGroupUpdated builds topic which listens for thing group updating event for specified groupName

func ThingTypeAssociation

func ThingTypeAssociation(thingName, typeName string) string

ThingTypeAssociation builds topic which listens for thing type association event for specified thingName & typeName

func ThingTypeCreated

func ThingTypeCreated(thingTypeName string) string

ThingTypeCreated builds topic which listens for thing type creation event for specified thingTypeName

func ThingTypeDeleted

func ThingTypeDeleted(thingTypeName string) string

ThingTypeDeleted builds topic which listens for thing type deletion event for specified thingTypeName

func ThingTypeUpdated

func ThingTypeUpdated(thingTypeName string) string

ThingTypeUpdated builds topic which listens for thing type updating event for specified thingTypeName

func ThingUpdated

func ThingUpdated(thingName string) string

ThingUpdated builds topic which listens for thing updating event for specified thingName

Types

This section is empty.

Jump to