Documentation
¶
Overview ¶
Package lifecycle provides topics to intercept thing lifecycle & subscription events
Index ¶
Constants ¶
const ( // AnyConnected : When subscribed to this topic gives events for all devices connecting to the iot gateway AnyConnected string = connected + "+" // AnyDisconnected : When subscribed to this topic gives events for all devices disconnected from the iot gateway AnyDisconnected string = disconnected + "+" // AnySubscribed : When subscribed to this topic gives events for all subscriptions being performed on iot gateway AnySubscribed string = subscribed + "+" // AnyUnsubscribed : When subscribed to this topic gives events for all unsubscribe operations being performed on iot gateway AnyUnsubscribed string = unsubscribed + "+" )
Variables ¶
This section is empty.
Functions ¶
func ClientConnected ¶
ClientConnected builds topic which will listen to connection event for clientId
func ClientDisconnected ¶
ClientDisconnected builds topic which will listen to disconnection event for clientId
func OnSubscribed ¶
OnSubscribed builds topic which will listen to all subscription events for specified topic
func OnUnsubscribed ¶
OnUnsubscribed builds topic which will listen to all unsubscribe events for specified topic
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.