Documentation
¶
Overview ¶
Package registry provides topics for Device registry operations
Index ¶
- func ThingCreated(thingName string) string
- func ThingDeleted(thingName string) string
- func ThingGroupCreated(groupName string) string
- func ThingGroupDeleted(groupName string) string
- func ThingGroupHierarchyAdded(parentThingGroupName, childThingGroupName string) string
- func ThingGroupHierarchyRemoved(parentThingGroupName, childThingGroupName string) string
- func ThingGroupMembershipAdded(thingGroupName, thingName string) string
- func ThingGroupMembershipRemoved(thingGroupName, thingName string) string
- func ThingGroupUpdated(groupName string) string
- func ThingTypeAssociation(thingName, typeName string) string
- func ThingTypeCreated(thingTypeName string) string
- func ThingTypeDeleted(thingTypeName string) string
- func ThingTypeUpdated(thingTypeName string) string
- func ThingUpdated(thingName string) string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ThingCreated ¶
ThingCreated builds topic which listens for thing creation event for specified thingName
func ThingDeleted ¶
ThingDeleted builds topic which listens for thing deletion event for specified thingName
func ThingGroupCreated ¶
ThingGroupCreated builds topic which listens for thing group creation event for specified groupName
func ThingGroupDeleted ¶
ThingGroupDeleted builds topic which listens for thing group deleting event for specified groupName
func ThingGroupHierarchyAdded ¶
ThingGroupHierarchyAdded builds topic which listens for change in thing group hierarchy for addition event with specified parentThingGroupName & childThingGroupName
func ThingGroupHierarchyRemoved ¶
ThingGroupHierarchyRemoved builds topic which listens for change in thing group hierarchy for removal event with specified parentThingGroupName & childThingGroupName
func ThingGroupMembershipAdded ¶
ThingGroupMembershipAdded builds topic which listens for thing group membership addition event for specified thingGroupName & thingName
func ThingGroupMembershipRemoved ¶
ThingGroupMembershipRemoved builds topic which listens for thing group membership removal event for specified thingGroupName & thingName
func ThingGroupUpdated ¶
ThingGroupUpdated builds topic which listens for thing group updating event for specified groupName
func ThingTypeAssociation ¶
ThingTypeAssociation builds topic which listens for thing type association event for specified thingName & typeName
func ThingTypeCreated ¶
ThingTypeCreated builds topic which listens for thing type creation event for specified thingTypeName
func ThingTypeDeleted ¶
ThingTypeDeleted builds topic which listens for thing type deletion event for specified thingTypeName
func ThingTypeUpdated ¶
ThingTypeUpdated builds topic which listens for thing type updating event for specified thingTypeName
func ThingUpdated ¶
ThingUpdated builds topic which listens for thing updating event for specified thingName
Types ¶
This section is empty.