Documentation
¶
Index ¶
- func GetKeywords(text string, minLen int, includeSpecialChars bool) []string
- func GetKeywordsProgression(text string, minLen int) []string
- func GetKeywordsSorted(text string, minLen int, includeSpecialChars bool) []string
- func MapKeywords(text string, minLen int, includeSpecialChars bool) map[string]int
- type Graph
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetKeywordsProgression ¶
GetKeywordsProgression generate an array of keywords with also partial words like ["word", "wor", "wo"]. This is useful searching for partial words
func GetKeywordsSorted ¶
Types ¶
type Graph ¶
type Graph struct {
// contains filtered or unexported fields
}
Graph holds node and edge data.
func (*Graph) Link ¶
Link creates a weighted edge between a source-target node pair. If the edge already exists, the weight is incremented.
Click to show internal directories.
Click to hide internal directories.